details {
    border: 1px solid #aaa;
    border-radius: 4px;
    padding: .5em .5em 0;
}

summary {
    font-weight: bold;
    margin: -.5em -.5em 0;
    padding: .5em;
    white-space: nowrap;
}

details[open] {
    padding: .5em;
}

details[open] summary {
    border-bottom: 1px solid #aaa;
    margin-bottom: .5em;
}

tbody tr:hover {
    background-color:whitesmoke;
    opacity: 0.9;
    transition: 0.1s;
}

.pf-c-form-control {
    width: 175px;
}

.pf-c-alert p {
    font-size: 0.8em;
}

#host-details pre {
    white-space: pre-wrap;
}

#result-details pre {
    white-space: pre-wrap;
}
