<!DOCTYPE html>
<html lang="en" class="layout-pf">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}{% endblock %}</title>
    <link rel="stylesheet" href="{% if page != "index" %}../{% endif %}static/css/patternfly.min.css">
    <link rel="stylesheet" href="{% if page != "index" %}../{% endif %}static/css/ara.css">
    {% if file.id or record.id or host.id or result.id %}
    <link rel="stylesheet" href="{% if page != "index" %}../{% endif %}static/css/pygments.css">
    {% endif %}
    <link rel="shortcut icon" href="{% if page != "index" %}../{% endif %}static/images/favicon.ico">
    {% block head %}
    {% endblock %}
</head>

<body>
    <div class="pf-c-page">
        <header role="banner" class="pf-c-page__header">
            <div class="pf-c-page__header-brand">
                {% if static_generation %}
                <a class="pf-c-page__header-brand-link" href="{% if page != "index" %}../{% endif %}">
                {% else %}
                <a class="pf-c-page__header-brand-link" href="{% url 'ui:index' %}">
                {% endif %}
                    <img class="pf-c-brand" src="{% if page != "index" %}../{% endif %}static/images/logo.svg" alt="ARA Records Ansible">
                </a>
            </div>
            <div class="pf-c-page__header-nav">
                <nav class="pf-c-nav" aria-label="Global">
                    <button class="pf-c-nav__scroll-button" aria-label="Scroll left">
                        <i class="fas fa-angle-left" aria-hidden="true"></i>
                    </button>
                    <ul class="pf-c-nav__horizontal-list">
                        <li class="pf-c-nav__item">
                            {% if page == "index" %}
                            <a href="{% if not static_generation %}{% url 'ui:index' %}{% endif %}" class="pf-c-nav__link pf-m-current" aria-current="page">Playbooks</a>
                            {% else %}
                            <a href="{% if not static_generation %}{% url 'ui:index' %}{% else %}../{% endif %}" class="pf-c-nav__link">Playbooks</a>
                            {% endif %}
                        </li>
                        {% include "partials/api_link.html" %}
                        <li class="pf-c-nav__item">
                            <a href="https://ara.readthedocs.io" class="pf-c-nav__link" target="_blank">Docs</a>
                        </li>
                    </ul>
                </nav>
            </div>
        </header>
        <main role="main" class="pf-c-page__main">
            <section class="pf-c-page__main-section pf-m-light">
                {% block body %}
                {% endblock %}
            </section>
            <section class="pf-c-page__main-section">
            </section>
        </main>
    </div>
</body>

</html>